<%inherit file="/pagetemplate.html" /> <%block name="title">Mixer
Fader 3-Band EQ {{i}} {{i}} {{recorderPortName}}

Preset:

### Audio ports

#### Inputs(Sources)

{{i}}

#### Outputs(Sinks)

{{i}}

### MIDI ports

#### Outputs(Sinks)

{{i}}

#### Inputs(Sources)

{{i}}

## Presets

Presets let you load and save the entire state of the mixing board. When kaithem boots, the preset named "default" will be loaded if it exists. Presets are saved immediately to vardir/system.mixer/presets

Name | Actions
--- | ---
{{i}} |  |

### Loading Mixer Channels

This may take a while if kaithem has just booted up.

### {{channelname}}({{channel.channels}})

{{channelStatus[channelname]}}

Image file(Relative to media/ in this module
Setup
In:

{{effect.displayType}}

### Add Effect

Connect output:

FBX Threshold:

dB

### Mixer Controls

#### New Channel

### Recorder ({{recordStatus}})

Route your audio to the input(Named {{recorderPortName}}) to use this.
Files in VARDIR/recordings/mixer

Channels:

File Prefix: